@@ -1,3 +1,5 @@
+from typing import Optional
+
 from cognite.client import utils
 from cognite.client._api_client import APIClient
 from cognite.client.data_classes import TransformationDestination, TransformationSchemaColumnList
@@ -7,11 +9,14 @@ class TransformationSchemaAPI(APIClient):
     _RESOURCE_PATH = "/transformations/schema"
     _LIST_CLASS = TransformationSchemaColumnList
 
-    def retrieve(self, destination: TransformationDestination = None) -> TransformationSchemaColumnList:
+    def retrieve(
+        self, destination: TransformationDestination = None, conflict_mode: Optional[str] = None
+    ) -> TransformationSchemaColumnList:
         """`Get expected schema for a transformation destination. <https://docs.cognite.com/api/v1/#operation/getTransformationSchema>`_
 
         Args:
             destination (TransformationDestination): destination for which the schema is requested.
+            conflict_mode (Optional[str]): conflict mode for which the schema is requested.
 
         Returns:
             TransformationSchemaColumnList: List of column descriptions
@@ -27,5 +32,19 @@ class TransformationSchemaAPI(APIClient):
         """
 
         url_path = utils._auxiliary.interpolate_and_url_encode(self._RESOURCE_PATH + "/{}", str(destination.type))
+        other_params = {"conflictMode": conflict_mode} if conflict_mode else None
+        return self._list(method="GET", resource_path=url_path, filter=other_params)
 
-        return self._list(method="GET", resource_path=url_path)
+    def _alpha_retrieve_data_model_schema(
+        self, modelExternalId: str = None, spaceExternalId: str = None, instanceExternalId: str = None
+    ) -> TransformationSchemaColumnList:
+        url_path = utils._auxiliary.interpolate_and_url_encode(self._RESOURCE_PATH + "/{}", "alphadatamodelinstances")
+        return self._list(
+            method="GET",
+            resource_path=url_path,
+            filter={
+                "externalId": modelExternalId,
+                "spaceExternalId": spaceExternalId,
+                "instanceExternalId": instanceExternalId,
+            },
+        )
