@@ -253,6 +253,10 @@ class TimeSeriesUpdate(CogniteUpdate):
     def description(self):
         return TimeSeriesUpdate._PrimitiveTimeSeriesUpdate(self, "description")
 
+    @property
+    def is_step(self):
+        return TimeSeriesUpdate._PrimitiveTimeSeriesUpdate(self, "isStep")
+
     @property
     def security_categories(self):
         return TimeSeriesUpdate._ListTimeSeriesUpdate(self, "securityCategories")
